@@ -1,5 +1,5 @@
 package USPS::RateRequest;
-$USPS::RateRequest::VERSION = '1.0002';
+$USPS::RateRequest::VERSION = '1.0003';
 use strict;
 use Moose;
 use XML::DOM;
@@ -16,7 +16,7 @@ USPS::RateRequest - Ultra fast parallelized asyncronous USPS rate lookups.
 
 =head1 VERSION
 
-version 1.0002
+version 1.0003
 
 =head1 SYNOPSIS
 
@@ -513,6 +513,9 @@ sub sanitize_service_name {
     $name =~ s/ Mail//gi;
     $name =~ s/ \d-Day//gi;
     $name =~ s/ APO\/FPO\/DPO//gi;
+    $name =~ s/ APO//gi;
+    $name =~ s/ DPO//gi;
+    $name =~ s/ FPO//gi;
     $name =~ s/ Military//gi;
     $name =~ s/ International//gi;
     $name =~ s/USPS //gi;
